# -*- coding: utf-8 -*-

from django.shortcuts import render, get_object_or_404, redirect
from django.template.loader import render_to_string
from django.db.models import Q
from lib.access_auth import permission_needed, access_inp
from lib.tools import confirmation
from portailuser.models import Ecole
from datetime import datetime, timedelta

from evenements.forms import EvenementForm
from evenements.models import Evenement


# Nombre maximal d'événements affichés sur le Widget.
NB_EVENEMENTS_AFFICHES = 5
# Nombre de jours avant un événement avant qu'il ne soit affiché sur le Widget.
NB_JOURS_AVANCE = 14
# Couleur de la tête du widget Evenements.
COULEUR_WIDGET = "magenta"


@access_inp
def widget(request):
    # On commence à afficher les événements NB_JOURS_AVANCE avant leur début…
    debut = datetime.now() + timedelta(days=NB_JOURS_AVANCE)
    # … et on arrête de les afficher 1h après leur fin.
    fin = datetime.now() - timedelta(hours=1)
    filtre = (Q(ecole=request.ecole) | Q(ecole=Ecole.inp)) & Q(date_heure_debut__lt=debut) & Q(date_heure_fin__gt=fin)

    evenements = Evenement.objects.filter(filtre).order_by("date_heure_debut")

    if not evenements:
        return None

    c = {
        "evenements": evenements,
    }

    return (render_to_string("evenements/widget.html", c), COULEUR_WIDGET)


@permission_needed("gerer_evenements")
def liste(request):
    c = {"evenements": Evenement.objects.filter(ecole=request.ecole).order_by("date_heure_debut")}

    return render(request, "evenements/liste.html", c)


@permission_needed("gerer_evenements")
def edition(request, id=None):
    # Permet d'éditer / créer un événement.
    if id is not None:
        evenement = get_object_or_404(Evenement, ecole=request.ecole, id=id)
    else:
        evenement = None

    if request.method == "POST":
        form = EvenementForm(data=request.POST, files=request.FILES, instance=evenement)
        # if evenement:
        #    form.fields['image'].required = False

        if form.is_valid():
            evenement = form.save(commit=False)
            evenement.ecole = request.ecole
            if not evenement.responsable:
                evenement.responsable = request.user
            evenement.save()
            # if 'image' in request.FILES:
            #    evenement.enregistrer_image(request.FILES['image'])
            return redirect("gestion:evenements:liste")

    else:
        form = EvenementForm(instance=evenement)
        # if evenement:
        #    form.fields['image'].required = False

    c = {
        "evenement": evenement,
        "form": form,
    }

    return render(request, "evenements/edition.html", c)


@permission_needed("gerer_evenements")
def suppression(request, id):
    # Permet de supprimer un événement.
    evenement = get_object_or_404(Evenement, ecole=request.ecole, id=id)

    if request.method == "POST":
        if "conf_ok" in request.POST:
            evenement.delete()
        return redirect("gestion:evenements:liste")

    message = """Êtes-vous sûr(e) de vouloir supprimer cet événement ?"""
    boutons = [("conf_annul", "Annuler"), ("conf_ok", "Supprimer")]

    return confirmation(request, message, boutons, "Supprimer un événement")


def evenementEstValide(request, id):
    return bool(Evenement.objects.filter(ecole=request.ecole, id=id))
